%define upstream_name    Hash-SafeKeys
%define upstream_version 0.04

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 8

Summary:    Get hash contents without resetting each iterator
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Hash/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(Test::More)
BuildRequires: perl-devel
%description
Every hash variable in Perl has its own internal iterator, accessed by the
builtin 'each', 'keys', and 'values' functions. The iterator is also
implicitly used whenever the hash is evaluated in list context. The
iterator is "reset" whenever 'keys' or 'values' is called on a hash,
including the implicit calls when the hash is evaluated in list context.
That makes it dangerous to do certain hash operations inside a 'while ...
each' loop:

    while (my($k,$v) = each %hash) {
       ...
       @k = sort keys %hash;               # Infinite loop!
       @v = grep { /foo/ }, values %hash;  # Ack!
       print join ' ', %hash;              # Run away!
    }

'Hash::SafeKeys' provides alternate functions to access the keys, values,
or entire contents of a hash in a way that does not reset the iterator,
making them safe to use in such contexts:

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%__perl Makefile.PL INSTALLDIRS=vendor

%make_build

%check
%make_build test

%install
%make_install

%files
%doc Changes META.json META.yml MYMETA.yml README
%{_mandir}/man3/*
%{perl_vendorarch}/*


%changelog
* Wed Jun 17 2020 umeabot <umeabot> 0.40.0-8.mga8
+ Revision: 1594806
- Rebuild for perl 5.32

* Sat Feb 15 2020 umeabot <umeabot> 0.40.0-7.mga8
+ Revision: 1529098
- Mageia 8 Mass Rebuild

* Tue Aug 27 2019 tv <tv> 0.40.0-6.mga8
+ Revision: 1433090
- rebuild with perl-5.30

* Fri Sep 21 2018 umeabot <umeabot> 0.40.0-5.mga7
+ Revision: 1293191
- Mageia 7 Mass Rebuild

* Wed Aug 08 2018 pterjan <pterjan> 0.40.0-4.mga7
+ Revision: 1249486
- Rebuild for perl 5.28

* Mon Oct 02 2017 tv <tv> 0.40.0-3.mga7
+ Revision: 1164753
- rebuild with fixed rpm for missing autodeps

* Thu Aug 31 2017 pterjan <pterjan> 0.40.0-2.mga7
+ Revision: 1148947
- Rebuild for perl ABI changes

* Mon Jul 31 2017 sander85 <sander85> 0.40.0-1.mga7
+ Revision: 1133247
- update to 0.04

* Sat Jul 22 2017 neoclust <neoclust> 0.30.0-11.mga7
+ Revision: 1126552
- Rebuild against new Perl 5.26

* Sun Jun 19 2016 pterjan <pterjan> 0.30.0-10.mga6
+ Revision: 1028203
- Rebuild for perl 5.22.2

* Fri Feb 12 2016 umeabot <umeabot> 0.30.0-9.mga6
+ Revision: 957460
- Mageia 6 Mass Rebuild

* Thu Jun 25 2015 sander85 <sander85> 0.30.0-8.mga6
+ Revision: 843295
- Rebuild for perl 5.22

* Wed Oct 15 2014 umeabot <umeabot> 0.30.0-7.mga5
+ Revision: 743098
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.30.0-6.mga5
+ Revision: 685033
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 pterjan <pterjan> 0.30.0-5.mga5
+ Revision: 631284
- Rebuild for perl 5.20

* Sat Oct 19 2013 umeabot <umeabot> 0.30.0-4.mga4
+ Revision: 524343
- Mageia 4 Mass Rebuild

* Wed May 29 2013 jquelin <jquelin> 0.30.0-3.mga4
+ Revision: 430748
- perl 5.18.0 rebuild

* Sun Jan 13 2013 umeabot <umeabot> 0.30.0-2.mga3
+ Revision: 368408
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 13 2012 shlomif <shlomif> 0.30.0-1.mga3
+ Revision: 330225
- update to 0.03

* Fri Jun 15 2012 shlomif <shlomif> 0.20.0-1.mga3
+ Revision: 260759
- imported package perl-Hash-SafeKeys


* Fri Jun 15 2012 cpan2dist 0.02-1mga
- initial mageia release, generated with cpan2dist
